@@ -1,11 +1,10 @@
 package MooseX::Runnable::Invocation::MxRun;
-{
-  $MooseX::Runnable::Invocation::MxRun::VERSION = '0.06';
-}
 BEGIN {
   $MooseX::Runnable::Invocation::MxRun::AUTHORITY = 'cpan:JROCKWAY';
 }
+$MooseX::Runnable::Invocation::MxRun::VERSION = '0.07';
 use Moose;
+use namespace::autoclean;
 
 extends 'MooseX::Runnable::Invocation';
 with 'MooseX::Runnable::Invocation::Role::WithParsedArgs';
